@@ -1,6 +1,6 @@
 from functools import reduce
 from hashlib import sha1
-from operator import or_
+from operator import add, or_
 
 from django import forms
 
@@ -16,17 +16,22 @@ class FormMixin:
     def get_form_fields(self, item):
         return self._f3f_item_fields[item]
 
+    def clean(self):
+        data = super().clean()
+        for hook in self._f3f_cleaners:
+            data = hook(self, data)
+        return data
+
 
 def create_form(items, *, form_class=forms.Form, form_kwargs):
-    item_fields = {
-        item: item.get_fields() for item in items if isinstance(item, FormFieldBase)
-    }
+    field_items = [item for item in items if isinstance(item, FormFieldBase)]
+    item_fields = {item: item.get_fields() for item in field_items}
     all_fields = reduce(or_, item_fields.values(), {})
     all_names = set(all_fields)
 
     initial = reduce(
         or_,
-        (item.get_initial() for item in items if isinstance(item, FormFieldBase)),
+        (item.get_initial() for item in field_items),
         {},
     )
     form_kwargs["initial"] = initial | form_kwargs.get("initial", {})
@@ -36,5 +41,6 @@ def create_form(items, *, form_class=forms.Form, form_kwargs):
         item: {name: form[name] for name in fields}
         for item, fields in item_fields.items()
     } | {None: {name: form[name] for name in form.fields if name not in all_names}}
+    form._f3f_cleaners = reduce(add, (item.get_cleaners() for item in field_items), [])
 
     return form
